@@ -4,6 +4,7 @@ from .models import Post, CATEGORY
 from django.views import generic
 from hitcount.views import HitCountDetailView
 from .forms import Search
+from util_demian import utils
 
 import logging
 logger = logging.getLogger(__name__)
@@ -13,6 +14,14 @@ ch.setFormatter(formatter)
 logger.addHandler(ch)
 logger.setLevel(logging.INFO)
 
+num_pagination = 7
+
+
+def robots(request):
+    from django.shortcuts import HttpResponse
+    file_content = utils.make_robots()
+    return HttpResponse(file_content, content_type="text/plain")
+
 
 def home(request):
     """
@@ -38,7 +47,7 @@ def contact(request):
 
 class Category(generic.ListView):
     template_name = 'zenblog/category.html'
-    paginate_by = 4
+    paginate_by = num_pagination
 
     def get_queryset(self):
         return Post.objects.filter(status=1).filter(category=self.kwargs['category_int']).order_by('-updated_on')
@@ -61,7 +70,7 @@ class Category(generic.ListView):
 
 class SearchResult(generic.ListView):
     template_name = 'zenblog/search-result.html'
-    paginate_by = 4
+    paginate_by = num_pagination
 
     def get_queryset(self):
         form = Search(self.request.GET)
